;; Generated package description from wfnames.el  -*- no-byte-compile: t -*-
(define-package "wfnames" "1.2.0.20260105.45812" "Edit filenames" '((emacs "24.4")) :commit "6ea49841ab76f44c0164b9f4722da2f9d46228da" :authors '(("Thierry Volpiatto" . "thievol@posteo.net")) :maintainer '("Thierry Volpiatto" . "thievol@posteo.net") :keywords '("wfnames" "convenience" "files" "editing" "helm") :url "https://github.com/thierryvolpiatto/wfnames")
